namespace Tarpit;

public static class WordUtils
{
    public static Dictionary<string, List<string>> LoadData(string filePath)
    {
        Dictionary<string, List<string>> wordFrequencies = new();
        
        using StreamReader reader = new(filePath);
        string? previousWord = null;
        
        while (reader.ReadLine() is { } line)
        {
            string[] words = line.Split(new char[] { ' ', '.', ',', '!', '?', ';', ':', '(', ')', '\n', '\r', '\t' }, StringSplitOptions.RemoveEmptyEntries);
            
            for (int i = 0; i < words.Length; i++)
            {
                string word = words[i];
                if (previousWord != null)
                {
                    if (!wordFrequencies.ContainsKey(previousWord))
                    {
                        wordFrequencies[previousWord] = [];
                    }
                    
                    wordFrequencies[previousWord].Add(word);
                }
                
                previousWord = word;
            }
        }
        
        return wordFrequencies;
    }
    
    public static List<string> PredictNextWords(string inputWord, Dictionary<string, List<string>> wordFrequencies)
    {
        if (!wordFrequencies.ContainsKey(inputWord.ToLower()))
        {
            return [];
        }
        
        List<string> nextWords = wordFrequencies[inputWord.ToLower()];
        
        List<string> words = [];
        
        for (int i = 0; i < 10; i++)
        {
            string? mostFrequentWord = nextWords
                .GroupBy(w => w)
                .OrderByDescending(g => g.Count())
                .ElementAtOrDefault(i)
                ?.Key;
            
            if (!string.IsNullOrEmpty(mostFrequentWord))
            {
                words.Add(mostFrequentWord);
            }
        }
        
        return words;
    }

    public static string[] CreateStartwords(string path)
    {
        
        
        return ["The"];
    }
}